pub struct Normalizer<P: ReferenceProvider> { /* private fields */ }Expand description
Main normalizer struct
Implementations
Sourceimpl<P: ReferenceProvider> Normalizer<P>
impl<P: ReferenceProvider> Normalizer<P>
Sourcepub fn with_config(provider: P, config: NormalizeConfig) -> Self
pub fn with_config(provider: P, config: NormalizeConfig) -> Self
Create a normalizer with custom configuration
Sourcepub fn config(&self) -> &NormalizeConfig
pub fn config(&self) -> &NormalizeConfig
Get the configuration
Sourcepub fn normalize(
&self,
variant: &HgvsVariant,
) -> Result<HgvsVariant, FerroError>
pub fn normalize( &self, variant: &HgvsVariant, ) -> Result<HgvsVariant, FerroError>
Normalize a variant
In strict mode (default), rejects variants with reference mismatches.
Use normalize_with_warnings for lenient mode that corrects mismatches.
Sourcepub fn normalize_with_warnings(
&self,
variant: &HgvsVariant,
) -> Result<NormalizeResultWithWarnings, FerroError>
pub fn normalize_with_warnings( &self, variant: &HgvsVariant, ) -> Result<NormalizeResultWithWarnings, FerroError>
Normalize a variant with detailed warnings
Returns the normalized variant along with any warnings generated during normalization (e.g., reference sequence mismatches that were auto-corrected). Use this method when you want to track what corrections were made.