Module python_helpers

Module python_helpers 

Helper functions for Python bindings

These functions are separated from the PyO3 code so they can be unit tested without requiring the Python runtime.

Functions

edit_type_from_debug
Get the edit type from debug string representation
get_variant_edit_type
Get the edit type string for any HgvsVariant
get_variant_reference
Get the reference accession from a variant
mu_na_edit_type_str
Get the edit type from a Mu-wrapped NaEdit
na_edit_type_str
Get the edit type as a string from an NaEdit
parse_direction
Parse a direction string into ShuffleDirection
variant_type_str
Get the variant type as a string