Helper functions for Python bindings
These functions are separated from the PyO3 code so they can be unit tested without requiring the Python runtime.
Functions
- edit_
type_ from_ debug - Get the edit type from debug string representation
- get_
variant_ edit_ type - Get the edit type string for any HgvsVariant
- get_
variant_ reference - Get the reference accession from a variant
- mu_
na_ edit_ type_ str - Get the edit type from a Mu-wrapped NaEdit
- na_
edit_ type_ str - Get the edit type as a string from an NaEdit
- parse_
direction - Parse a direction string into ShuffleDirection
- variant_
type_ str - Get the variant type as a string