pub fn get_variant_reference(
variant: &HgvsVariant,
) -> Result<String, &'static str>Expand description
Get the reference accession from a variant
Returns the accession string for variants that have one, or an error message for variants that don’t support accessions.
Examples
use ferro_hgvs::python_helpers::get_variant_reference;
use ferro_hgvs::parse_hgvs;
let variant = parse_hgvs("NC_000001.11:g.12345A>G").unwrap();
assert_eq!(get_variant_reference(&variant).unwrap(), "NC_000001.11");